/**
 * \file    tictactoe.h
 * \brief   Engine for TicTacToe game
 * \author  Philippe Lucidarme
 * \version 1.0
 * \date    18 mars 2011
 *
 * This class is an engine for the TicTacToe game
 *
 */

#ifndef TICTACTOE_H
#define TICTACTOE_H


/*! \def    EMPTY
    \brief  Value set in an empty cell */
#define     EMPTY       0
/*! \def    CROSS
    \brief  Value used to describe the mark of the first player  */
#define     CROSS       1
/*! \def    CIRCLE
    \brief  Value used to describe the mark of the second player */
#define     CIRCLE      2
/*! \def    DRAW
    \brief  Value used to describe a draw game  */
#define     DRAW        3



using namespace std;

/*!  \class     TicTacToe
     \brief     This class can managed a Tic-Tac-Toe game. The class allows basic operations like initializing the game, placing marks according to the rules,
                checking if the game is over, undo a move etc ...
     \example    TicTacToe_Example.cpp
   */

class TicTacToe
{


public:


    TicTacToe(void);                        // Constructor
    void    DrawGame(void);                 // Draw the game in text mode
    void    Reset(void);                    // Set the game in its initial configuration
    char    CurrentPlayer(void);            // Return the mark of the current player (CROSS or CIRCLE)
    char    Play(int NumCell);              // Play a move in the cell NumCell
    int     Undo(void);                     // Undo the last move
    char    GameOver(void);                 // Return the state of the game (endded, draw ...)


private:
    char    Grid[9];                        // Playground
    int     NumMoves;                       // Number of moves since the beginning
    int     History[9];                     // History of the game (each move)
};

#endif // TICTACTOE_H

/*!
  \mainpage Tic-Tac-Toe class

  \brief
       \htmlonly
            <a href="../TicTacToev2.0.zip" title="Download the Tic-Tac-Toe class">
                <TABLE>
                <TR><TD><IMG SRC="download.png" BORDER=0 WIDTH=100> </TD></TR>
                <TR><TD><P ALIGN="center">[Download]</P> </TD></TR>
                </TABLE>
            </A>
            <BR/>

        \endhtmlonly

    The class TicTacToe manages a 3x3 Tic-Tac-Toe game.
    \image html xo.jpg
    The class allows basic operations like :
    - initializing the game
    - placing marks on the grid
    - checking if the game is over
    - analysing the status of the game
    - undo a move

  \author   Philippe Lucidarme
  \date     19 mars 2011
  \todo     Currently, the game is only for a 3x3 grid. It can be extended to an NxN game.
  \todo     Using an enumaration type for the elements of the game would be better
  \todo     Returning a string in the function DrawGame would be better
  \todo     Cells are currently numerized from 0 to 9, two dimentionnal identification of the cell would be easier for the user.
  \todo     Change the image for a swd image made
  \version  1.0
*/

